@@ -6,7 +6,7 @@ use JSON;
 use REST::Client;
 use MIME::Base64;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     my ($class, $args) = @_;
@@ -130,6 +130,23 @@ JIRA::REST::Lite - A lightweight Perl module for interacting with JIRA REST API
       },
   });
 
+  # Get issue
+  $issue = $jira->GET("/issue/TST-101");
+
+  # Iterate on issues
+  $jira->set_search_iterator({
+      jql        => 'project = "TST" and status = "open"',
+      maxResults => 16,
+      fields     => [ qw/summary status assignee/ ],
+  });
+
+  while (my $issue = $jira->next_issue) {
+      print "Found issue $issue->{key}\n";
+  }
+
+  # Attach files
+  $jira->attach_files('TST-123', '/path/to/doc.txt', 'image.png');
+
 =head1 DESCRIPTION
 
 JIRA::REST::Lite provides a simple interface for interacting with the JIRA REST API, with minimal dependencies.
